@@ -51,7 +51,7 @@ class BasePo(object):
         if isinstance(page, Page):
             page_url_prefix = page.url.split("?")[0]
             url_prefix = url.split("?")[0]
-            if page_url_prefix.endswith(url_prefix):
+            if page_url_prefix.endswith(url_prefix) or url_prefix.lower() in page_url_prefix.lower():
                 return True
             else:
                 return False
